<template>
    <el-dialog
        :visible.sync="personPurchaseDetailVisible"
        :close-on-click-modal="false"
        width="60%"
    >
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="personPurchaseDetailData"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="流向码" prop="directioncode" align="center">
                </el-table-column>
                <el-table-column label="购买单号" prop="ordercode" align="center">
                </el-table-column>
                <el-table-column label="产品名称" prop="itemname" align="center">
                </el-table-column>
                <el-table-column label="产品编号" prop="itemcode" align="center">
                </el-table-column>
                <el-table-column label="规格" prop="specification" align="center">
                </el-table-column>
                <el-table-column label="价格" prop="price" align="center">
                </el-table-column>
                <el-table-column label="购买时间" prop="createdat" align="center">
                </el-table-column>
                <el-table-column label="是否退货" prop="returnflag" align="center" >
                    <template slot-scope="scope">
                        {{scope.row.returnflag === 1 ? "√":""}}
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
    </el-dialog>
</template>

<script>
import {getPersonDetailListData} from "@/api/productPurchaseSearch";
import {computePageCount} from "../../../utils";
import {getDLPersonDetailListData} from "../../../api/productPurchaseSearch";

export default {
    name: "index",
    data(){
        return{
            tableKey:'',
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            personPurchaseDetailData:[],
            personPurchaseDetailVisible:false,
            listQuery: {
                pageSize:10,
                pageIndex:1,
                filter: {
                    starttime: '',
                    endtime: '',
                    identify: '',
                    enterprisenumber: '',
                    directionCode:'',
                },
            },
        }
    },
    created() {

    },
    methods:{
        openPersonPurchaseDetail(startTime,endTime,identify,enterpriseNumber,directionCode,type){
            this.listQuery.filter.starttime = startTime
            this.listQuery.filter.endtime = endTime
            this.listQuery.filter.identify = identify
            this.listQuery.filter.enterprisenumber = enterpriseNumber
            this.listQuery.filter.directioncode = directionCode
            this.listQuery.pageIndex = 1;
            this.listQuery.pageSize = 10;
            this.personPurchaseDetailVisible = true
            if(type == 1){
                this.getPersonProductDetailList()
            }else{
                this.getDLPersonProductDetailList()
            }
        },
         async getPersonProductDetailList(){
            this.listLoading = true
            let res = await getPersonDetailListData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.personPurchaseDetailData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        async getDLPersonProductDetailList(){
            this.listLoading = true
            let res = await getDLPersonDetailListData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.personPurchaseDetailData = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        handleSizeChange(val) {
            this.listQuery.pageSize = val
            this.getPersonProductDetailList()
        },
        handleCurrentChange(val) {
            this.listQuery.pageIndex = val
            this.getPersonProductDetailList()
        },
    }
}
</script>

<style scoped>

</style>
